from messanger_lite.server.server import check_and_create_answer_to_client
from messanger_lite.client.common import ACTION, ACCOUNT_NAME, ERROR, PRESENCE, RESPONSE,\
    TIME, USER
import sys
import os
import unittest
sys.path.append(os.path.join(os.getcwd(), '../../..'))


class TestServer(unittest.TestCase):
    """ Класс с тестами """
    correct_dict = {RESPONSE: 200}
    error_dict = {RESPONSE: 400, ERROR: 'Bad Request'}

    def test_ok_check(self):
        self.assertEqual(check_and_create_answer_to_client({
            ACTION: PRESENCE, TIME: 1, USER: {
                ACCOUNT_NAME: 'Guest'
            }
        }), self.correct_dict)

    def test_no_action(self):
        self.assertEqual(check_and_create_answer_to_client({
            TIME: 1, USER: {ACCOUNT_NAME: 'Guest'}
        }), self.error_dict)

    def test_wrong_action(self):
        self.assertEqual(check_and_create_answer_to_client({
            ACTION: 'Test wrong action', TIME: 1, USER: {ACCOUNT_NAME: 'Guest', }
        }), self.error_dict)

    def test_no_time_in_response(self):
        self.assertEqual(check_and_create_answer_to_client({
            ACTION: PRESENCE, USER: {ACCOUNT_NAME: 'Guest'}
        }), self.error_dict)

    def test_no_user(self):
        self.assertEqual(check_and_create_answer_to_client({
            ACTION: PRESENCE, TIME: 1
        }), self.error_dict)

    def test_wrong_account_name(self):
        self.assertEqual(check_and_create_answer_to_client({
            ACTION: PRESENCE, TIME: 1, USER: {ACCOUNT_NAME: 'Wrong name'}
        }), self.error_dict)


if __name__ == '__main__':
    unittest.main()



"""Модуль приветствия клиентского приложения."""
from PyQt5.QtWidgets import QDialog, QPushButton, QLineEdit, QApplication, \
    QLabel, qApp


class UserNameDialog(QDialog):
    """
    Класс создающий приветственный диалог с запросом имени пользователя и
    пароля.
    """

    def __init__(self):
        super().__init__()

        self.ok_pressed = False

        self.setWindowTitle('Привет!')
        self.setFixedSize(265, 190)

        self.label = QLabel('Имя пользователя:', self)
        self.label.move(10, 10)
        self.label.setFixedSize(180, 25)

        self.client_name = QLineEdit(self)
        self.client_name.setFixedSize(180, 25)
        self.client_name.move(10, 35)

        self.btn_ok = QPushButton('Начать', self)
        self.btn_ok.move(10, 140)
        self.btn_ok.clicked.connect(self.click)

        self.btn_cancel = QPushButton('Выход', self)
        self.btn_cancel.move(140, 140)
        self.btn_cancel.clicked.connect(qApp.exit)

        self.label_passwd = QLabel('Введите пароль:', self)
        self.label_passwd.move(10, 70)
        self.label_passwd.setFixedSize(180, 25)

        self.client_passwd = QLineEdit(self)
        self.client_passwd.setFixedSize(180, 25)
        self.client_passwd.move(10, 95)
        self.client_passwd.setEchoMode(QLineEdit.Password)

        self.show()

    def click(self):
        """
        Обработчик кнопки ОК, если поле ввода не пустое, ставим флаг и
        завершаем приложение.
        """
        if self.client_name.text():
            self.ok_pressed = True
            qApp.exit()


if __name__ == '__main__':
    app = QApplication([])
    dial = UserNameDialog()
    app.exec_()



"""Модуль создания основного клиентского окна."""
from PyQt5 import QtCore, QtWidgets
from messanger_lite.client.common.variables import WINDOW_WIGHT, WINDOW_HEIGHT


class Ui_MainClientWindow(object):
    """Класс - основного окна клиента."""

    def setupUi(self, MainClientWindow):
        MainClientWindow.setObjectName("MainClientWindow")
        MainClientWindow.resize(WINDOW_WIGHT, WINDOW_HEIGHT)
        MainClientWindow.setMinimumSize(QtCore.QSize(WINDOW_WIGHT,
                                                     WINDOW_HEIGHT))
        self.centralwidget = QtWidgets.QWidget(MainClientWindow)
        self.centralwidget.setObjectName("central_widget")
        self.label_contacts = QtWidgets.QLabel(self.centralwidget)
        self.label_contacts.setGeometry(QtCore.QRect(15, 15, 150, 20))
        self.label_contacts.setObjectName("label_contacts")
        self.btn_add_contact = QtWidgets.QPushButton(self.centralwidget)
        self.btn_add_contact.setGeometry(QtCore.QRect(15, 500, 160, 30))
        self.btn_add_contact.setObjectName("btn_add_contact")
        self.btn_remove_contact = QtWidgets.QPushButton(self.centralwidget)
        self.btn_remove_contact.setGeometry(QtCore.QRect(195, 500, 160, 30))
        self.btn_remove_contact.setObjectName("btn_remove_contact")
        self.label_history = QtWidgets.QLabel(self.centralwidget)
        self.label_history.setGeometry(QtCore.QRect(380, 15, 390, 20))
        self.label_history.setObjectName("label_history")
        self.text_message = QtWidgets.QTextEdit(self.centralwidget)
        self.text_message.setGeometry(QtCore.QRect(380, 400, 550, 80))
        self.text_message.setObjectName("text_message")
        self.label_new_message = QtWidgets.QLabel(self.centralwidget)
        self.label_new_message.setGeometry(QtCore.QRect(380, 370, 520, 20))
        self.label_new_message.setObjectName("label_new_message")
        self.list_contacts = QtWidgets.QListView(self.centralwidget)
        self.list_contacts.setGeometry(QtCore.QRect(15, 40, 340, 450))
        self.list_contacts.setObjectName("list_contacts")
        self.list_messages = QtWidgets.QListView(self.centralwidget)
        self.list_messages.setGeometry(QtCore.QRect(380, 40, 550, 320))
        self.list_messages.setObjectName("list_messages")
        self.btn_send = QtWidgets.QPushButton(self.centralwidget)
        self.btn_send.setGeometry(QtCore.QRect(670, 500, 180, 30))
        self.btn_send.setObjectName("btn_send")
        self.btn_clear = QtWidgets.QPushButton(self.centralwidget)
        self.btn_clear.setGeometry(QtCore.QRect(430, 500, 180, 30))
        self.btn_clear.setObjectName("btn_clear")
        MainClientWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainClientWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 756, 25))
        self.menubar.setObjectName("menubar")
        self.menu = QtWidgets.QMenu(self.menubar)
        self.menu.setObjectName("menu")
        self.menu_2 = QtWidgets.QMenu(self.menubar)
        self.menu_2.setObjectName("menu_2")
        MainClientWindow.setMenuBar(self.menubar)
        self.statusBar = QtWidgets.QStatusBar(MainClientWindow)
        self.statusBar.setObjectName("statusBar")
        MainClientWindow.setStatusBar(self.statusBar)
        self.menu_exit = QtWidgets.QAction(MainClientWindow)
        self.menu_exit.setObjectName("menu_exit")
        self.menu_add_contact = QtWidgets.QAction(MainClientWindow)
        self.menu_add_contact.setObjectName("menu_add_contact")
        self.menu_del_contact = QtWidgets.QAction(MainClientWindow)
        self.menu_del_contact.setObjectName("menu_del_contact")
        self.menu.addAction(self.menu_exit)
        self.menu_2.addAction(self.menu_add_contact)
        self.menu_2.addAction(self.menu_del_contact)
        self.menu_2.addSeparator()
        self.menubar.addAction(self.menu.menuAction())
        self.menubar.addAction(self.menu_2.menuAction())

        self.retranslateUi(MainClientWindow)
        self.btn_clear.clicked.connect(self.text_message.clear)
        QtCore.QMetaObject.connectSlotsByName(MainClientWindow)

    def retranslateUi(self, MainClientWindow):
        _translate = QtCore.QCoreApplication.translate
        MainClientWindow.setWindowTitle(_translate(
            "MainClientWindow", "Чат Программа release 0.1"))
        self.label_contacts.setText(_translate("MainClientWindow",
                                               "Список контактов:"))
        self.btn_add_contact.setText(_translate("MainClientWindow",
                                                "Добавить контакт"))
        self.btn_remove_contact.setText(_translate("MainClientWindow",
                                                   "Удалить контакт"))
        self.label_history.setText(_translate("MainClientWindow",
                                              "История сообщений:"))
        self.label_new_message.setText(_translate("MainClientWindow",
                                                  "Введите новое сообщение:"))
        self.btn_send.setText(_translate("MainClientWindow",
                                         "Отправить сообщение"))
        self.btn_clear.setText(_translate("MainClientWindow", "Очистить поле"))
        self.menu.setTitle(_translate("MainClientWindow", "Файл"))
        self.menu_2.setTitle(_translate("MainClientWindow", "Контакты"))
        self.menu_exit.setText(_translate("MainClientWindow", "Выход"))
        self.menu_add_contact.setText(_translate("MainClientWindow",
                                                 "Добавить контакт"))
        self.menu_del_contact.setText(_translate("MainClientWindow",
                                                 "Удалить контакт"))



from setuptools import setup, find_packages

setup(
    name='messanger_lite_client',
    version='1.0.0',
    description='messanger_lite_client',
    author='Idel Yusupov',
    author_email='idel@mail.ru',
    packages=find_packages(),
    install_requires=['PyQt5', 'sqlalchemy', 'pycryptodome', 'pycryptodomex']
)